@@ -13,9 +13,8 @@ from deepdiff.helper import (strings, numbers, times, unprocessed, not_hashed, a
 from deepdiff.base import Base
 logger = logging.getLogger(__name__)
 
-UNPROCESSED_KEY = 'unprocessed'
+UNPROCESSED_KEY = object()
 
-RESERVED_DICT_KEYS = {UNPROCESSED_KEY}
 EMPTY_FROZENSET = frozenset()
 
 INDEX_VS_ATTRIBUTE = ('[%s]', '.%s')
@@ -63,13 +62,48 @@ class BoolObj(Enum):
     FALSE = 0
 
 
-def prepare_string_for_hashing(obj, ignore_string_type_changes=False, ignore_string_case=False):
+def prepare_string_for_hashing(
+        obj,
+        ignore_string_type_changes=False,
+        ignore_string_case=False,
+        encodings=None,
+        ignore_encoding_errors=False,
+):
     """
     Clean type conversions
     """
     original_type = obj.__class__.__name__
+    # https://docs.python.org/3/library/codecs.html#codecs.decode
+    errors_mode = 'ignore' if ignore_encoding_errors else 'strict'
     if isinstance(obj, bytes):
-        obj = obj.decode('utf-8')
+        err = None
+        encodings = ['utf-8'] if encodings is None else encodings
+        encoded = False
+        for encoding in encodings:
+            try:
+                obj = obj.decode(encoding, errors=errors_mode)
+                encoded = True
+                break
+            except UnicodeDecodeError as er:
+                err = er
+        if not encoded:
+            obj_decoded = obj.decode('utf-8', errors='ignore')
+            start = min(err.start - 10, 0)
+            start_prefix = ''
+            if start > 0:
+                start_prefix = '...'
+            end = err.end + 10
+            end_suffix = '...'
+            if end >= len(obj):
+                end = len(obj)
+                end_suffix = ''
+            raise UnicodeDecodeError(
+                err.encoding,
+                err.object,
+                err.start,
+                err.end,
+                f"{err.reason} in '{start_prefix}{obj_decoded[start:end]}{end_suffix}'. Please either pass ignore_encoding_errors=True or pass the encoding via encodings=['utf-8', '...']."
+            ) from None
     if not ignore_string_type_changes:
         obj = KEY_TO_VAL_STR.format(original_type, obj)
     if ignore_string_case:
@@ -105,6 +139,8 @@ class DeepHash(Base):
                  number_to_string_func=None,
                  ignore_private_variables=True,
                  parent="root",
+                 encodings=None,
+                 ignore_encoding_errors=False,
                  **kwargs):
         if kwargs:
             raise ValueError(
@@ -113,7 +149,8 @@ class DeepHash(Base):
                  "exclude_paths, exclude_regex_paths, hasher, ignore_repetition, "
                  "number_format_notation, apply_hash, ignore_type_in_groups, ignore_string_type_changes, "
                  "ignore_numeric_type_changes, ignore_type_subclasses, ignore_string_case "
-                 "number_to_string_func, ignore_private_variables, parent") % ', '.join(kwargs.keys()))
+                 "number_to_string_func, ignore_private_variables, parent "
+                 "encodings, ignore_encoding_errors") % ', '.join(kwargs.keys()))
         if isinstance(hashes, MutableMapping):
             self.hashes = hashes
         elif isinstance(hashes, DeepHash):
@@ -147,6 +184,8 @@ class DeepHash(Base):
         self.type_check_func = type_is_subclass_of_type_group if ignore_type_subclasses else type_in_type_group
         self.number_to_string = number_to_string_func or number_to_string
         self.ignore_private_variables = ignore_private_variables
+        self.encodings = encodings
+        self.ignore_encoding_errors = ignore_encoding_errors
 
         self._hash(obj, parent=parent, parents_ids=frozenset({get_id(obj)}))
 
@@ -185,7 +224,7 @@ class DeepHash(Base):
             except KeyError:
                 raise KeyError(HASH_LOOKUP_ERR_MSG.format(obj)) from None
 
-        if isinstance(obj, strings) and obj in RESERVED_DICT_KEYS:
+        if obj is UNPROCESSED_KEY:
             extract_index = None
 
         return result_n_count if extract_index is None else result_n_count[extract_index]
@@ -229,7 +268,7 @@ class DeepHash(Base):
         """
         result = dict_()
         for key, value in self.hashes.items():
-            if key in RESERVED_DICT_KEYS:
+            if key is UNPROCESSED_KEY:
                 result[key] = value
             else:
                 result[key] = value[extract_index]
@@ -421,8 +460,12 @@ class DeepHash(Base):
 
         elif isinstance(obj, strings):
             result = prepare_string_for_hashing(
-                obj, ignore_string_type_changes=self.ignore_string_type_changes,
-                ignore_string_case=self.ignore_string_case)
+                obj,
+                ignore_string_type_changes=self.ignore_string_type_changes,
+                ignore_string_case=self.ignore_string_case,
+                encodings=self.encodings,
+                ignore_encoding_errors=self.ignore_encoding_errors,
+            )
 
         elif isinstance(obj, times):
             result = self._prep_datetime(obj)
